Description Usage Arguments Examples
View source: R/calc_crop_sale_price.R
Calculates the expected value of a crop to sell, taking into account the probability of extra harvests and the number of crops in an extra harvest.
1 2 3 4 5 | calc_crop_sale_price(
crop_data = croptimizer::crops,
farming_level = 0,
level_5_tiller = NULL
)
|
crop_data |
data.frame containing crop data, which must contain the columns 'sell_price', 'chance_for_extra_crops', 'max_extra_harvest' |
farming_level |
integer representing current farming level |
level_5_tiller |
logical representing taking the tiller specialization at level 5 |
1 2 3 4 5 | ## Calculate crop sale prices if you have tiller specialty
calc_crop_sale_price(farming_level = 5, level_5_tiller = TRUE)
## Calculate crop sale price if you did not take tiller
calc_crop_sale_price(farming_level = 10, level_5_tiller = FALSE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.